@@ -1,17 +1,10 @@
-#include <sys/stat.h>
 #include <sys/types.h>
 
-#include <ctype.h>
 #include <err.h>
-#include <errno.h>
-#include <fcntl.h>
-#include <limits.h>
-#include <stdarg.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 
 #include "util.h"
 
