@@ -1,10 +1,8 @@
 #include <sys/types.h>
 
-#include <ctype.h>
 #include <err.h>
 #include <locale.h>
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
