@@ -1,7 +1,7 @@
-#include <ctype.h>
+#include <sys/types.h>
+
 #include <err.h>
 #include <stdio.h>
-#include <stdlib.h>
 #include <string.h>
 #include <time.h>
 
