@@ -1,12 +1,7 @@
-#include <sys/types.h>
-
 #include <ctype.h>
 #include <err.h>
 #include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
 #include <strings.h>
-#include <time.h>
 
 #include "util.h"
 #include "xml.h"
@@ -30,8 +25,6 @@ static void
 xmltagstart(XMLParser *p, const char *t, size_t tl)
 {
 	isbase = islink = isfeedlink = 0;
-	if (tl != 4) /* optimization */
-		return;
 
 	if (!strcasecmp(t, "base"))
 		isbase = 1;
@@ -59,9 +52,6 @@ static void
 xmlattr(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
 	const char *v, size_t vl)
 {
-	if (nl != 4) /* optimization */
-		return;
-
 	if (isbase) {
 		if (!strcasecmp(n, "href"))
 			strlcpy(basehref, v, sizeof(basehref));
